;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ebib-sidecar" "20251029.1934"
  "Sidecar to show formatted reference of current Ebib Entry."
  '((emacs                      "28.1")
    (citeproc                   "0.9.4")
    (universal-sidecar          "1.5.1")
    (universal-sidecar-citeproc "1.0.0")
    (ebib                       "2.39"))
  :url "https://git.sr.ht/~swflint/emacs-universal-sidecar"
  :commit "01b12aecca0ce66f5427e7fe65012d37e7e128b2"
  :revdesc "01b12aecca0c"
  :keywords '("bib")
  :authors '(("Samuel W. Flint" . "me@samuelwflint.com"))
  :maintainers '(("Samuel W. Flint" . "me@samuelwflint.com")))
